﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Interactivity;
using Infragistics.Controls.Schedules;
using System.Collections.Specialized;
using System.Windows;
using System.Collections;

namespace XamDateNavigator_Behavior
{
    public class XamDateNavigatorSelectedDatesBehavior : Behavior<XamDateNavigator>
    {
        private XamDateNavigator DateNavigator
        {
            get { return AssociatedObject as XamDateNavigator; }
        }

        public INotifyCollectionChanged SelectedDates
        {
            get { return (INotifyCollectionChanged)GetValue(SelectedDatesProperty); }
            set { SetValue(SelectedDatesProperty, value); }
        }

        public static readonly DependencyProperty SelectedDatesProperty = DependencyProperty.Register(
         "SelectedDates",
         typeof(INotifyCollectionChanged),
         typeof(XamDateNavigatorSelectedDatesBehavior),
         null);

        protected override void OnAttached()
        {
            base.OnAttached();
            SubscribeToEvents();
        }

        private void ContextSelectedDates_CollectionChanged(Object sender, NotifyCollectionChangedEventArgs e)
        {
            UnsubscribeFromEvents();
            Transfer(SelectedDates as IList, DateNavigator.SelectedDates);
            SubscribeToEvents();
        }

        private void SelectedDates_CollectionChanged(Object sender, NotifyCollectionChangedEventArgs e)
        {
            UnsubscribeFromEvents();
            Transfer(DateNavigator.SelectedDates, SelectedDates as IList);
            SubscribeToEvents();
        }

        private void SubscribeToEvents()
        {
            DateNavigator.SelectedDates.CollectionChanged += SelectedDates_CollectionChanged;

            if (SelectedDates != null)
            {
                SelectedDates.CollectionChanged += ContextSelectedDates_CollectionChanged;
            }
        }

        private void UnsubscribeFromEvents()
        {
            DateNavigator.SelectedDates.CollectionChanged -= SelectedDates_CollectionChanged;

            if (SelectedDates != null)
            {
                SelectedDates.CollectionChanged -= ContextSelectedDates_CollectionChanged;
            }
        }

        public static void Transfer(IList source, IList target)
        {
            if (source == null || target == null) { return; }

            target.Clear();

            foreach (var o in source)
            {
                target.Add(o);
            }
        }
    }
}
